@@ -42,23 +42,35 @@ class LineParser(object):
 
 class DiffWriter(object):
 
-    colors = {
-        'metaline':      'darkyellow',
-        'plain':         'darkwhite',
-        'newtext':       'darkblue',
-        'oldtext':       'darkred',
-        'diffstuff':     'darkgreen',
-        'trailingspace': 'yellow',
-        'leadingtabs':   'magenta',
-        'longline':      'cyan',
-    }
-
-    def __init__(self, target, check_style):
+    def __init__(self, target, check_style=False, color='always'):
         self.target = target
         self.lp = LineParser()
         self.chunks = []
-        self._read_colordiffrc('/etc/colordiffrc')
-        self._read_colordiffrc(expanduser('~/.colordiffrc'))
+        from terminal import has_ansi_colors
+        if 'always' == color or ('auto' == color and has_ansi_colors()):
+            self.colors = {
+                'metaline':      'darkyellow',
+                'plain':         'darkwhite',
+                'newtext':       'darkblue',
+                'oldtext':       'darkred',
+                'diffstuff':     'darkgreen',
+                'trailingspace': 'yellow',
+                'leadingtabs':   'magenta',
+                'longline':      'cyan',
+            }
+            self._read_colordiffrc('/etc/colordiffrc')
+            self._read_colordiffrc(expanduser('~/.colordiffrc'))
+        else:
+            self.colors = {
+                'metaline':      None,
+                'plain':         None,
+                'newtext':       None,
+                'oldtext':       None,
+                'diffstuff':     None,
+                'trailingspace': None,
+                'leadingtabs':   None,
+                'longline':      None,
+            }
         self.added_leading_tabs = 0
         self.added_trailing_whitespace = 0
         self.spurious_whitespace = 0
@@ -179,9 +191,13 @@ class DiffWriter(object):
         self._old_lines, self._new_lines = ([], [])
 
 
-def colordiff(check_style, *args, **kwargs):
+def auto_diff_writer(output):
+    return DiffWriter(output, color='auto')
+
+
+def colordiff(color, check_style, *args, **kwargs):
     real_stdout = sys.stdout
-    dw = DiffWriter(real_stdout, check_style)
+    dw = DiffWriter(real_stdout, check_style, color)
     sys.stdout = dw
     try:
         get_cmd_object('diff').run(*args, **kwargs)
