@@ -17,9 +17,6 @@
 
 import os
 
-class NoPyBaz(Exception):
-    def __init__(self):
-        Exception.__init__(self, "PyBaz is not installed.")
 try:
     from bzrlib.errors import BzrCommandError as CommandError
     from bzrlib.errors import BzrError
@@ -77,3 +74,11 @@ class NoParent(CommandError):
 class ChangedBinaryFiles(BzrError):
 
     _fmt = 'Changes involve binary files.'
+
+
+class NoConflictFiles(CommandError):
+
+    _fmt = '%(base_name)s does not exist and there are no pending merges.'
+
+    def __init__(self, base_name):
+        CommandError.__init__(self, base_name=base_name)
