@@ -119,9 +119,11 @@ class TestImport(TestCaseInTempDir):
             f.write('Now?')
             f.close()
             archive_file.add(prefix + 'README')
-            archive_file.close()
 
-            archive_file = builder(result, 'a')
+            f = file(prefix + 'README', 'wb')
+            f.write('Wow?')
+            f.close()
+            # Add a second entry for README with different contents.
             archive_file.add(prefix + 'README')
             archive_file.close()
 
@@ -218,6 +220,9 @@ class TestImport(TestCaseInTempDir):
             archive_file = self.make_archive2(builder, subdir)
             importer(tree, archive_file)
             self.assertTrue(tree.path2id('README') is not None)
+            # Ensure the second version of the file is used.
+            self.assertEqual(tree.get_file_text(tree.path2id('README')),
+                             'Wow?')
             self.assertTrue(not os.path.exists(tree.abspath('FEEDME')))
         finally:
             tree.unlock()
